@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -29,9 +29,10 @@
 using namespace PimCommon;
 
 GoogleTranslator::GoogleTranslator(QObject *parent)
-    : QObject(parent),
-      mNetworkAccessManager(new QNetworkAccessManager(this))
+    : QObject(parent)
+    , mNetworkAccessManager(new QNetworkAccessManager(this))
 {
+    mDebug = !qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING");
     connect(mNetworkAccessManager, &QNetworkAccessManager::finished, this, &GoogleTranslator::slotTranslateFinished);
 }
 
@@ -39,6 +40,11 @@ GoogleTranslator::~GoogleTranslator()
 {
 }
 
+void GoogleTranslator::setParentWidget(QWidget *parent)
+{
+    mParentWidget = parent;
+}
+
 void GoogleTranslator::setInputText(const QString &text)
 {
     mInputText = text;
@@ -166,7 +172,7 @@ void GoogleTranslator::translate()
     const QNetworkRequest request(url);
 
     QNetworkReply *reply = mNetworkAccessManager->get(request);
-    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &GoogleTranslator::slotError);
+    connect(reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::error), this, &GoogleTranslator::slotError);
 }
 
 void GoogleTranslator::slotError(QNetworkReply::NetworkError /*error*/)
@@ -192,9 +198,9 @@ void GoogleTranslator::slotTranslateFinished(QNetworkReply *reply)
         return;
     }
     const QVariantList json = jsonDoc.toVariant().toList();
-#if !defined(NDEBUG)
-    mJsonDebug = QString::fromUtf8(jsonDoc.toJson(QJsonDocument::Indented));
-#endif
+    if (mDebug) {
+        mJsonDebug = QString::fromUtf8(jsonDoc.toJson(QJsonDocument::Indented));
+    }
     for (const QVariant &level0 : json) {
         const QVariantList listLevel0 = level0.toList();
         if (listLevel0.isEmpty()) {
@@ -212,12 +218,12 @@ void GoogleTranslator::slotTranslateFinished(QNetworkReply *reply)
 
 void GoogleTranslator::debug()
 {
-#if !defined(NDEBUG)
-    QPointer<TranslatorDebugDialog> dlg = new TranslatorDebugDialog;
-    dlg->setDebug(mJsonDebug);
-    dlg->exec();
-    delete dlg;
-#endif
+    if (mDebug) {
+        QPointer<TranslatorDebugDialog> dlg = new TranslatorDebugDialog(mParentWidget);
+        dlg->setDebug(mJsonDebug);
+        dlg->exec();
+        delete dlg;
+    }
 }
 
 void GoogleTranslator::clear()
