@@ -30,9 +30,7 @@ class QAbstractItemModel;
 class QAction;
 class QItemSelectionModel;
 
-namespace PimCommon
-{
-
+namespace PimCommon {
 class PIMCOMMONAKONADI_TESTS_EXPORT AclManager : public QObject
 {
     Q_OBJECT
@@ -113,14 +111,8 @@ private:
     //@cond PRIVATE
     class Private;
     Private *const d;
-
-    Q_PRIVATE_SLOT(d, void selectionChanged())
-    Q_PRIVATE_SLOT(d, void addAcl())
-    Q_PRIVATE_SLOT(d, void editAcl())
-    Q_PRIVATE_SLOT(d, void deleteAcl())
     //@endcond
 };
-
 }
 
 #endif
